import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { FiSearch, FiX } from 'react-icons/fi';
import { useMedia } from '../../contexts/MediaContext';

function SearchBar({ onClose }) {
  const [query, setQuery] = useState('');
  const { handleSearch, searchResults, loading } = useMedia();
  const navigate = useNavigate();

  const handleSubmit = (e) => {
    e.preventDefault();
    if (query.trim()) {
      navigate(`/search?q=${encodeURIComponent(query)}`);
      if (onClose) onClose();
    }
  };

  const handleChange = (e) => {
    const value = e.target.value;
    setQuery(value);
    
    // Debounce search as user types
    const timeoutId = setTimeout(() => {
      if (value.trim().length > 2) {
        handleSearch(value);
      }
    }, 500);

    return () => clearTimeout(timeoutId);
  };

  const handleResultClick = (id, mediaType) => {
    navigate(`/media/${id}?type=${mediaType}`);
    if (onClose) onClose();
  };

  return (
    <div className="relative">
      <form onSubmit={handleSubmit} className="relative">
        <input
          type="text"
          value={query}
          onChange={handleChange}
          placeholder="Search for movies, TV shows, games..."
          className="w-full bg-campfire-dark border border-campfire-ash rounded-full px-5 py-3 pl-12 text-campfire-light focus:ring-2 focus:ring-campfire-amber focus:border-transparent outline-none"
        />
        <FiSearch className="absolute left-4 top-1/2 transform -translate-y-1/2 text-campfire-ash" size={18} />
        {query && (
          <button
            type="button"
            onClick={() => setQuery('')}
            className="absolute right-16 top-1/2 transform -translate-y-1/2 text-campfire-ash hover:text-campfire-light"
          >
            <FiX size={18} />
          </button>
        )}
        <button
          type="submit"
          className="absolute right-3 top-1/2 transform -translate-y-1/2 bg-campfire-amber text-campfire-dark rounded-full px-4 py-1 text-sm font-medium hover:bg-campfire-ember transition-colors"
        >
          Search
        </button>
      </form>

      {/* Quick results dropdown */}
      {query.trim().length > 2 && searchResults.length > 0 && (
        <div className="absolute z-10 mt-2 w-full bg-campfire-charcoal rounded-md shadow-lg max-h-96 overflow-y-auto">
          <div className="py-2">
            {loading ? (
              <div className="px-4 py-2 text-campfire-ash">Loading...</div>
            ) : (
              searchResults.slice(0, 5).map((item) => (
                <div
                  key={item.id}
                  onClick={() => handleResultClick(item.id, item.media_type)}
                  className="px-4 py-2 hover:bg-campfire-dark cursor-pointer flex items-center"
                >
                  {item.poster_path ? (
                    <img
                      src={`https://image.tmdb.org/t/p/w92${item.poster_path}`}
                      alt={item.title || item.name}
                      className="w-10 h-14 object-cover rounded mr-3"
                    />
                  ) : (
                    <div className="w-10 h-14 bg-campfire-dark rounded mr-3 flex items-center justify-center text-campfire-ash">
                      No image
                    </div>
                  )}
                  <div>
                    <div className="font-medium text-campfire-light">
                      {item.title || item.name}
                    </div>
                    <div className="text-sm text-campfire-ash">
                      {item.media_type === 'movie' ? 'Movie' : 'TV Show'} • {item.release_date?.substring(0, 4) || item.first_air_date?.substring(0, 4) || 'Unknown'}
                    </div>
                  </div>
                </div>
              ))
            )}
            {searchResults.length > 5 && (
              <div 
                className="px-4 py-2 text-center text-campfire-amber cursor-pointer hover:underline"
                onClick={() => {
                  navigate(`/search?q=${encodeURIComponent(query)}`);
                  if (onClose) onClose();
                }}
              >
                See all results
              </div>
            )}
          </div>
        </div>
      )}
    </div>
  );
}

export default SearchBar;