import React, { useEffect, useState } from 'react';
import { useMedia } from '../contexts/MediaContext';
import { listMedia } from '../services/supabase';
import { mediaTypes } from '../services/mediaService';
import { useAuth } from "../contexts/AuthContext";
import { useNavigate } from "react-router-dom";
import { createMedia } from "../services/supabase";

const AdminMediaPage = () => {
  const [media, setMedia] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const navigate = useNavigate();
  const { currentUser, userProfile } = useAuth();
  const [page, setPage] = useState(1);
  const [hasMore, setHasMore] = useState(true);

  const [mediaData, setMediaData] = useState({
    title: "",
    type: "movie",
    poster_url: "",
    backdrop_url: "",
    overview: "",
    release_date: "",
    is_published: false,
  });

  // Проверка прав доступа
  if (!userProfile?.role || !["admin", "editor"].includes(userProfile.role)) {
    return (
      <div className="pt-20 container-custom py-12">
        <div className="bg-status-error bg-opacity-20 text-status-error p-6 rounded-lg">
          <h2 className="text-xl font-bold mb-2">Доступ запрещен</h2>
          <p>У вас нет прав для доступа к этой странице.</p>
        </div>
      </div>
    );
  }

  useEffect(() => {
    const fetchMedia = async () => {
      try {
        setLoading(true);
        setError(null);
        const data = await listMedia(null, 1, 100); // Получаем все медиа
        setMedia(data || []);
      } catch (err) {
        console.error('Error fetching media:', err);
        setError('Не удалось загрузить медиа');
      } finally {
        setLoading(false);
      }
    };

    fetchMedia();
  }, []); // Запускаем только при монтировании компонента

  const handleInputChange = (e) => {
    const { name, value, type, checked } = e.target;
    setMediaData((prev) => ({
      ...prev,
      [name]: type === "checkbox" ? checked : value,
    }));
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setLoading(true);
    setError("");

    try {
      const newMedia = await createMedia({
        ...mediaData,
        created_by: currentUser.id,
      });

      setMedia(prev => [newMedia, ...prev]);
      setMediaData({
        title: "",
        type: "movie",
        poster_url: "",
        backdrop_url: "",
        overview: "",
        release_date: "",
        is_published: false,
      });
    } catch (err) {
      setError("Ошибка при создании медиа. Пожалуйста, попробуйте снова.");
      console.error("Error creating media:", err);
    } finally {
      setLoading(false);
    }
  };

  if (loading) {
    return <div className="text-center">Загрузка...</div>;
  }

  if (error) {
    return <div className="text-red-500">{error}</div>;
  }

  return (
    <div className="container mx-auto px-4 py-8">
      <h1 className="text-3xl font-bold mb-8">Управление медиа</h1>
      
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
        {media.map((item) => (
          <div key={`${item.id}-${item.type}`} className="bg-white rounded-lg shadow-md p-4">
            <h3 className="text-lg font-semibold mb-2">{item.title}</h3>
            <p className="text-gray-600 mb-2">Тип: {item.type}</p>
            {item.rating && (
              <p className="text-gray-600">Рейтинг: {item.rating}</p>
            )}
          </div>
        ))}
      </div>

      {/* Форма создания медиа */}
      <div className="bg-campfire-charcoal p-6 rounded-lg mb-8">
        <h2 className="text-2xl font-bold mb-4">Создать новое медиа</h2>
        {error && (
          <div className="bg-status-error bg-opacity-20 text-status-error p-4 rounded-lg mb-4">
            {error}
          </div>
        )}
        <form onSubmit={handleSubmit} className="space-y-4">
          <div>
            <label className="block text-sm font-medium mb-1">Название</label>
            <input
              type="text"
              name="title"
              value={mediaData.title}
              onChange={handleInputChange}
              required
              className="input w-full"
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium mb-1">Тип</label>
            <select
              name="type"
              value={mediaData.type}
              onChange={handleInputChange}
              className="input w-full"
            >
              <option value="movie">Фильм</option>
              <option value="series">Сериал</option>
              <option value="game">Игра</option>
            </select>
          </div>
          
          <div>
            <label className="block text-sm font-medium mb-1">URL постера</label>
            <input
              type="url"
              name="poster_url"
              value={mediaData.poster_url}
              onChange={handleInputChange}
              className="input w-full"
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium mb-1">URL фона</label>
            <input
              type="url"
              name="backdrop_url"
              value={mediaData.backdrop_url}
              onChange={handleInputChange}
              className="input w-full"
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium mb-1">Описание</label>
            <textarea
              name="overview"
              value={mediaData.overview}
              onChange={handleInputChange}
              className="input w-full h-32"
            />
          </div>
          
          <div>
            <label className="block text-sm font-medium mb-1">Дата выхода</label>
            <input
              type="date"
              name="release_date"
              value={mediaData.release_date}
              onChange={handleInputChange}
              className="input w-full"
            />
          </div>
          
          <div className="flex items-center">
            <input
              type="checkbox"
              name="is_published"
              checked={mediaData.is_published}
              onChange={handleInputChange}
              className="mr-2"
            />
            <label className="text-sm font-medium">Опубликовать сразу</label>
          </div>
          
          <button
            type="submit"
            disabled={loading}
            className="btn-primary w-full"
          >
            {loading ? "Создание..." : "Создать медиа"}
          </button>
        </form>
      </div>
    </div>
  );
};

export default AdminMediaPage;
