import { createClient } from '@supabase/supabase-js';

const supabaseUrl = import.meta.env.VITE_SUPABASE_URL;
const supabaseAnonKey = import.meta.env.VITE_SUPABASE_ANON_KEY;

if (!supabaseUrl || !supabaseAnonKey) {
  throw new Error('Missing Supabase environment variables');
}

export const supabase = createClient(supabaseUrl, supabaseAnonKey);

// Auth functions
export const signUp = async (email, password, username) => {
  try {
    // Регистрируем пользователя
    const { data, error } = await supabase.auth.signUp({
      email,
      password,
      options: {
        data: { username }
      }
    });
    
    if (error) throw error;
    
    // Создаем профиль в таблице users
    const { error: profileError } = await supabase
      .from('users')
      .insert({
        id: data.user.id,
        email,
        username,
        role: 'user',
        created_at: new Date().toISOString()
      });
    
    if (profileError) {
      // Если не удалось создать профиль, удаляем пользователя
      await supabase.auth.admin.deleteUser(data.user.id);
      throw profileError;
    }
    
    return data;
  } catch (error) {
    throw error;
  }
};

export const signIn = async (email, password) => {
  const { data, error } = await supabase.auth.signInWithPassword({ email, password });
  if (error) throw error;
  return data;
};

export const signOut = async () => {
  const { error } = await supabase.auth.signOut();
  if (error) throw error;
};

export const getCurrentUser = async () => {
  const { data: { user }, error } = await supabase.auth.getUser();
  if (error) throw error;
  return user;
};

// User functions
export const getUserProfile = async (userId) => {
  const { data, error } = await supabase
    .from('users')
    .select('*')
    .eq('id', userId)
    .maybeSingle();
  
  if (error) throw error;
  return data;
};

// Media functions
export const createMedia = async (mediaData) => {
  try {
    const { data: { user } } = await supabase.auth.getUser();
    if (!user) {
      throw new Error('Пользователь не авторизован');
    }

    const { data, error } = await supabase
      .from('media')
      .insert({
        ...mediaData,
        created_by: user.id,
        created_at: new Date().toISOString(),
        is_published: false
      })
      .select()
      .single();
    
    if (error) {
      console.error('Error creating media:', error);
      throw error;
    }
    
    return data;
  } catch (error) {
    console.error('Failed to create media:', error);
    throw error;
  }
};

export const getMediaById = async (id) => {
  const { data, error } = await supabase
    .from('media')
    .select(`
      *,
      created_by:users(username),
      reviews(
        *,
        user:users(username, profile_picture, is_critic)
      )
    `)
    .eq('id', id)
    .single();
  
  if (error) throw error;
  return data;
};

export const listMedia = async (type = null, page = 1, limit = 20) => {
  try {
    let query = supabase
      .from('media')
      .select('*', { count: 'exact' })
      .order('created_at', { ascending: false });

    if (type) {
      query = query.eq('type', type);
    }

    const { data, error, count } = await query
      .range((page - 1) * limit, page * limit - 1);

    if (error) throw error;

    return {
      data,
      count,
      error: null
    };
  } catch (error) {
    console.error('Error in listMedia:', error);
    return {
      data: [],
      count: 0,
      error: error.message
    };
  }
};

// Review functions
export const createReview = async (reviewData) => {
  const { data, error } = await supabase
    .from('reviews')
    .insert(reviewData)
    .select()
    .single();
  
  if (error) throw error;
  return data;
};

export const getUserReviews = async (userId) => {
  const { data, error } = await supabase
    .from('reviews')
    .select(`
      *,
      media(title, type, poster_url)
    `)
    .eq('user_id', userId)
    .order('created_at', { ascending: false });
  
  if (error) throw error;
  return data;
};